@@ -5,19 +5,14 @@
 namespace Icinga\Module\Icingadb\Controllers;
 
 use Icinga\Exception\NotFoundError;
-use Icinga\Module\Icingadb\Common\CommandActions;
-use Icinga\Module\Icingadb\Common\Links;
 use Icinga\Module\Icingadb\Model\Comment;
 use Icinga\Module\Icingadb\Web\Controller;
 use Icinga\Module\Icingadb\Widget\Detail\CommentDetail;
-use Icinga\Module\Icingadb\Widget\ItemList\CommentList;
+use Icinga\Module\Icingadb\Widget\Detail\ObjectHeader;
 use ipl\Stdlib\Filter;
-use ipl\Web\Url;
 
 class CommentController extends Controller
 {
-    use CommandActions;
-
     /** @var Comment The comment object */
     protected $comment;
 
@@ -49,24 +44,10 @@ class CommentController extends Controller
 
     public function indexAction()
     {
-        $this->addControl((new CommentList([$this->comment]))
-            ->setViewMode('minimal')
-            ->setDetailActionsDisabled()
-            ->setCaptionDisabled()
-            ->setNoSubjectLink());
+        $this->addControl(new ObjectHeader($this->comment));
 
         $this->addContent(new CommentDetail($this->comment));
 
         $this->setAutorefreshInterval(10);
     }
-
-    protected function fetchCommandTargets(): array
-    {
-        return [$this->comment];
-    }
-
-    protected function getCommandTargetsUrl(): Url
-    {
-        return Links::comment($this->comment);
-    }
 }
