@@ -42,7 +42,17 @@ trait Auth
             return StringHelper::trimSplit($restriction);
         }, $this->getAuth()->getRestrictions('icingadb/denylist/routes'))));
 
-        return ! array_key_exists($name, $routeDenylist);
+        if (! array_key_exists($name, $routeDenylist)) {
+            if ($name === 'contacts' && array_key_exists('users', $routeDenylist)) {
+                return false; // TODO: Remove with 1.3, compat only
+            } elseif ($name === 'contactgroups' && array_key_exists('usergroups', $routeDenylist)) {
+                return false; // TODO: Remove with 1.3, compat only
+            }
+
+            return true;
+        }
+
+        return false;
     }
 
     /**
@@ -201,8 +211,8 @@ trait Auth
             }
 
             $customVarRelationName = array_search('customvar_flat', $relations, true);
-            $applyServiceRestriction = in_array('service', $relations, true);
-            $applyHostRestriction = in_array('host', $relations, true)
+            $applyServiceRestriction = $relations[0] === 'dependency_node' || in_array('service', $relations, true);
+            $applyHostRestriction = $relations[0] === 'dependency_node' || in_array('host', $relations, true)
                 // Hosts and services have a special relation as a service can't exist without its host.
                 // Hence why the hosts restriction is also applied if only services are queried.
                 || $applyServiceRestriction;
@@ -238,8 +248,14 @@ trait Auth
                 }
 
                 if ($customVarRelationName === false || count($relations) > 1) {
-                    if (($restriction = $role->getRestrictions('icingadb/filter/objects'))) {
-                        $roleFilter->add($this->parseRestriction($restriction, 'icingadb/filter/objects'));
+                    if ($restriction = $role->getRestrictions('icingadb/filter/objects')) {
+                        $roleFilter->add(Filter::any(
+                            Filter::all(
+                                Filter::unlike('host.id', '*'),
+                                Filter::unlike('service.id', '*')
+                            ),
+                            $this->parseRestriction($restriction, 'icingadb/filter/objects')
+                        ));
                     }
 
                     if ($applyHostRestriction && ($restriction = $role->getRestrictions('icingadb/filter/hosts'))) {
@@ -248,7 +264,7 @@ trait Auth
                             $this->forceQueryOptimization($hostFilter, 'hostgroup.name');
                         }
 
-                        $roleFilter->add($hostFilter);
+                        $roleFilter->add(Filter::any(Filter::unlike('host.id', '*'), $hostFilter));
                     }
 
                     if (
