@@ -4,11 +4,12 @@
 
 namespace Icinga\Module\Icingadb\Common;
 
+use InvalidArgumentException;
 use ipl\Html\BaseHtmlElement;
 use ipl\Html\Html;
+use ipl\Html\HtmlElement;
 use ipl\Stdlib\BaseFilter;
 use ipl\Stdlib\Filter;
-use ipl\Web\Filter\QueryString;
 use ipl\Web\Url;
 use ipl\Web\Widget\Link;
 use ipl\Web\Widget\StateBadge;
@@ -26,7 +27,7 @@ abstract class StateBadges extends BaseHtmlElement
     /** @var string Prefix */
     protected $prefix;
 
-    /** @var Url Badge link */
+    /** @var ?Url Badge link */
     protected $url;
 
     protected $tag = 'ul';
@@ -46,13 +47,6 @@ abstract class StateBadges extends BaseHtmlElement
         $this->url = $this->getBaseUrl();
     }
 
-    /**
-     * Get the badge base URL
-     *
-     * @return Url
-     */
-    abstract protected function getBaseUrl(): Url;
-
     /**
      * Get the type of the items
      *
@@ -67,21 +61,36 @@ abstract class StateBadges extends BaseHtmlElement
      */
     abstract protected function getPrefix(): string;
 
+    /**
+     * Get the badge base URL
+     *
+     * @return ?Url
+     */
+    protected function getBaseUrl(): ?Url
+    {
+        return null;
+    }
+
     /**
      * Get the integer of the given state text
      *
      * @param string $state
      *
      * @return int
+     *
+     * @throws InvalidArgumentException if the given state is not valid
      */
-    abstract protected function getStateInt(string $state): int;
+    protected function getStateInt(string $state): int
+    {
+        throw new InvalidArgumentException(sprintf('%s is not a valid state', $state));
+    }
 
     /**
      * Get the badge URL
      *
-     * @return Url
+     * @return ?Url
      */
-    public function getUrl(): Url
+    public function getUrl(): ?Url
     {
         return $this->url;
     }
@@ -108,7 +117,7 @@ abstract class StateBadges extends BaseHtmlElement
      *
      * @return Link
      */
-    public function createLink($content, Filter\Rule $filter = null): Link
+    protected function createLink($content, Filter\Rule $filter = null): Link
     {
         $url = clone $this->getUrl();
 
@@ -135,18 +144,23 @@ abstract class StateBadges extends BaseHtmlElement
      *
      * @return ?BaseHtmlElement
      */
-    protected function createBadge(string $state)
+    protected function createBadge(string $state): ?BaseHtmlElement
     {
         $key = $this->prefix . "_{$state}";
-
-        if (isset($this->item->$key) && $this->item->$key) {
-            return Html::tag('li', $this->createLink(
-                new StateBadge($this->item->$key, $state),
-                Filter::equal($this->type . '.state.soft_state', $this->getStateInt($state))
-            ));
+        if (empty($this->item->$key)) {
+            return null;
         }
 
-        return null;
+        $stateBadge = new StateBadge($this->item->$key, $state);
+
+        if ($this->url !== null) {
+            $stateBadge = $this->createLink(
+                $stateBadge,
+                Filter::equal($this->type . '.state.soft_state', $this->getStateInt($state))
+            );
+        }
+
+        return new HtmlElement('li', null, $stateBadge);
     }
 
     /**
@@ -156,34 +170,46 @@ abstract class StateBadges extends BaseHtmlElement
      *
      * @return ?BaseHtmlElement
      */
-    protected function createGroup(string $state)
+    protected function createGroup(string $state): ?BaseHtmlElement
     {
         $content = [];
         $handledKey = $this->prefix . "_{$state}_handled";
         $unhandledKey = $this->prefix . "_{$state}_unhandled";
 
         if (isset($this->item->$unhandledKey) && $this->item->$unhandledKey) {
-            $content[] = Html::tag('li', $this->createLink(
-                new StateBadge($this->item->$unhandledKey, $state),
-                Filter::all(
-                    Filter::equal($this->type . '.state.soft_state', $this->getStateInt($state)),
-                    Filter::equal($this->type . '.state.is_handled', 'n'),
-                    Filter::equal($this->type . '.state.is_reachable', 'y')
-                )
-            ));
+            $unhandledStateBadge = new StateBadge($this->item->$unhandledKey, $state);
+
+            if ($this->url !== null) {
+                $unhandledStateBadge = $this->createLink(
+                    $unhandledStateBadge,
+                    Filter::all(
+                        Filter::equal($this->type . '.state.soft_state', $this->getStateInt($state)),
+                        Filter::equal($this->type . '.state.is_handled', 'n'),
+                        Filter::equal($this->type . '.state.is_reachable', 'y')
+                    )
+                );
+            }
+
+            $content[] = new HtmlElement('li', null, $unhandledStateBadge);
         }
 
         if (isset($this->item->$handledKey) && $this->item->$handledKey) {
-            $content[] = Html::tag('li', $this->createLink(
-                new StateBadge($this->item->$handledKey, $state, true),
-                Filter::all(
-                    Filter::equal($this->type . '.state.soft_state', $this->getStateInt($state)),
-                    Filter::any(
-                        Filter::equal($this->type . '.state.is_handled', 'y'),
-                        Filter::equal($this->type . '.state.is_reachable', 'n')
+            $handledStateBadge = new StateBadge($this->item->$handledKey, $state, true);
+
+            if ($this->url !== null) {
+                $handledStateBadge = $this->createLink(
+                    $handledStateBadge,
+                    Filter::all(
+                        Filter::equal($this->type . '.state.soft_state', $this->getStateInt($state)),
+                        Filter::any(
+                            Filter::equal($this->type . '.state.is_handled', 'y'),
+                            Filter::equal($this->type . '.state.is_reachable', 'n')
+                        )
                     )
-                )
-            ));
+                );
+            }
+
+            $content[] = new HtmlElement('li', null, $handledStateBadge);
         }
 
         if (empty($content)) {
