@@ -6,9 +6,17 @@ namespace Icinga\Module\Icingadb\Model;
 
 use ipl\Orm\Behavior\Binary;
 use ipl\Orm\Behaviors;
-use ipl\Orm\Model;
+use Icinga\Module\Icingadb\Common\Model;
 use ipl\Orm\Relations;
 
+/**
+ * @property string $id
+ * @property string $checkcommand_id
+ * @property string $envvar_key
+ * @property string $environment_id
+ * @property string $properties_checksum
+ * @property string $envvar_value
+ */
 class CheckcommandEnvvar extends Model
 {
     public function getTableName()
